@@ -6,7 +6,7 @@ use Moo;
 extends 'Data::Sah::Compiler::perl::TH';
 with 'Data::Sah::Type::array';
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 sub handle_type_check {
     my ($self, $cd) = @_;
@@ -42,27 +42,9 @@ sub superclause_comparable {
     );
 }
 
-sub superclause_sortable {
-    my ($self, $which, $cd) = @_;
-    my $c = $self->compiler;
-
-    $c->handle_clause(
-        $cd,
-        on_term => sub {
-            my ($self, $cd) = @_;
-            my $cv = $cd->{cl_value};
-            my $ct = $cd->{cl_term};
-            my $dt = $cd->{data_term};
-
-            # due to eq vs ==, it might be ambiguous
-            $self->_die("Sorry, '$which' for array is not implemented");
-        },
-    );
-}
-
 sub superclause_has_elems {
-    my ($self, $which, $cd) = @_;
-    my $c = $self->compiler;
+    my ($self_th, $which, $cd) = @_;
+    my $c = $self_th->compiler;
 
     $c->handle_clause(
         $cd,
@@ -88,8 +70,8 @@ sub superclause_has_elems {
                         $cd, "\@{$dt} >= $cv->[0] && \@{$dt} <= $cv->[1]");
                 }
             #} elsif ($which eq 'has') {
-            #} elsif ($which eq 'each_index') {
-            ###} elsif ($which eq 'each_elem') {
+            } elsif ($which eq 'each_index' || $which eq 'each_elem') {
+                $self_th->gen_each($which, $cd, "0..\@{$dt}-1", "\@{$dt}");
             #} elsif ($which eq 'check_each_index') {
             #} elsif ($which eq 'check_each_elem') {
             #} elsif ($which eq 'uniq') {
@@ -115,7 +97,7 @@ Data::Sah::Compiler::perl::TH::array - perl's type handler for type "array"
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 AUTHOR
 
